@@ -1,7 +1,7 @@
 package File::Digest;
 
 our $DATE = '2016-11-23'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use Log::Any::IfLOG '$log';
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(digest_files check_file_digest);
+our @EXPORT_OK = qw(digest_files);
 
 use Perinci::Object;
 
@@ -17,8 +17,7 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'Calculate and check file checksum/digest '.
-        '(using various algorithms)',
+    summary => 'Calculate file checksum/digest (using various algorithms)',
 };
 
 my %arg_file = (
@@ -52,7 +51,12 @@ my %arg_algorithm = (
 
 $SPEC{digest_file} = {
     v => 1.1,
-    summary => 'Calculate file checksums/digests (using various algorithms)',
+    summary => 'Calculate file checksum/digest (using various algorithms)',
+    description => <<'_',
+
+Return 400 status when algorithm is unknown/unsupported.
+
+_
     args => {
         %arg_file,
         %arg_algorithm,
@@ -95,8 +99,12 @@ sub digest_file {
 
 $SPEC{digest_files} = {
     v => 1.1,
-    summary => 'Calculate file checksums/digests (using various algorithms)',
+    summary => 'Calculate file checksum/digest (using various algorithms)',
+    description => <<'_',
 
+Dies when algorithm is unsupported/unknown.
+
+_
     args => {
         %arg_files,
         %arg_algorithm,
@@ -124,16 +132,8 @@ sub digest_files {
     $envres;
 }
 
-$SPEC{check_file_digest} = {
-    v => 1.1,
-    summary => 'Calculate file checksums/digests (using various algorithms)',
-};
-sub check_file_digest {
-    [501, "Not yet implemented"];
-}
-
 1;
-# ABSTRACT: Calculate and check file checksum/digest (using various algorithms)
+# ABSTRACT: Calculate file checksum/digest (using various algorithms)
 
 __END__
 
@@ -143,11 +143,11 @@ __END__
 
 =head1 NAME
 
-File::Digest - Calculate and check file checksum/digest (using various algorithms)
+File::Digest - Calculate file checksum/digest (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.004 of File::Digest (from Perl distribution File-Digest), released on 2016-11-23.
+This document describes version 0.005 of File::Digest (from Perl distribution File-Digest), released on 2016-11-23.
 
 =head1 SYNOPSIS
 
@@ -163,29 +163,11 @@ This document describes version 0.004 of File::Digest (from Perl distribution Fi
 =head1 FUNCTIONS
 
 
-=head2 check_file_digest() -> [status, msg, result, meta]
-
-Calculate file checksums/digests (using various algorithms).
-
-This function is not exported by default, but exportable.
-
-No arguments.
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (any)
-
-
 =head2 digest_file(%args) -> [status, msg, result, meta]
 
-Calculate file checksums/digests (using various algorithms).
+Calculate file checksum/digest (using various algorithms).
+
+Return 400 status when algorithm is unknown/unsupported.
 
 This function is not exported.
 
@@ -213,7 +195,9 @@ Return value:  (any)
 
 =head2 digest_files(%args) -> [status, msg, result, meta]
 
-Calculate file checksums/digests (using various algorithms).
+Calculate file checksum/digest (using various algorithms).
+
+Dies when algorithm is unsupported/unknown.
 
 This function is not exported by default, but exportable.
 
@@ -260,6 +244,9 @@ L<sum> from L<PerlPowerTools> (which only supports older algorithms like CRC32).
 
 Backend modules: L<Digest::CRC>, L<Digest::MD5>, L<Digest::SHA>.
 
+L<xsum> from L<App::xsum> which can also check checksums/digests from checksum
+file e.g. F<MD5SUMS>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
